/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import { Review } from "../../components/review";
import { Rule } from "../../components/rule";
import { Testimonials } from "../../config/Testimonials";
import type { JSX } from "react";

/**
 * Renders the /reviews page.
 * @returns A React Component.
 */
const Reviews = (): JSX.Element => {
  return (
    <main className="w-[95%] text-center max-w-4xl
    m-auto mt-16 mb-16 rounded-lg">
      <h1 className="text-5xl">{`Client Reviews`}</h1>
      <section>
        <p className="mb-2">
          {`We think we're pretty great to work with, but don't take
          our word for it. Here's what our clients have to say.`}
        </p>
        <Rule />
        <ol className="relative border-s border-[--primary] w-4/5 m-auto">
          {Testimonials.toSorted(
            (a, b) => {
              return b.date.getTime() - a.date.getTime();
            },
          ).map((review) => {
            return <Review
              content={review.content}
              date={review.date}
              key={review.date.toISOString()}
              name={review.name}
              sourceIcon={review.sourceIcon}
              sourceName={review.sourceName}
              sourceUrl={review.sourceUrl}
            />;
          })}
        </ol>
      </section>
    </main>
  );
};

export default Reviews;
