/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import Image from "next/image";
import type { JSX } from "react";

interface ArtProperties {
  readonly name:   string;
  readonly img:    string;
  readonly artist: string;
  readonly url:    string;
  readonly alt:    string;
}

/**
 * Renders the view for an art piece.
 * @param properties - The art to render.
 * @returns A JSX element.
 */
export const ArtComponent = (properties: ArtProperties): JSX.Element => {
  const { name, img, artist, url, alt } = properties;

  return (
    <div className="w-[300px] h-[300px] border-2
    border-solid border-[--foreground] m-auto text-center items-center">
      <p className="text-l">
        {`${name} by `}
        <a className="underline" href={url} rel="noreferrer" target="_blank">
          {artist}
        </a>
      </p>
      <a
        href={`https://cdn.nhcarrigan.com/art/${img}`}
        rel="noreferrer"
        target="_blank"
      >
        <Image
          alt={alt}
          className="m-auto object-contain  max-h-[250px] max-w-[250px]"
          height={250}
          src={`https://cdn.nhcarrigan.com/art/${img}`}
          width={250}
        />
      </a>
    </div>
  );
};
