/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import Image from "next/image";
import type { JSX } from "react";

interface CertProperties {
  readonly name:     string;
  readonly fileName: string;
  readonly issuer:   string;
  readonly date:     Date;
}

/**
 * Renders the view for a certification.
 * @param properties - The certification to render.
 * @returns A JSX element.
 */
export const Certification = (properties: CertProperties): JSX.Element => {
  const { name, fileName, issuer, date } = properties;

  return (
    <div className="w-[300px] h-[300px] border-2
      border-solid border-[--foreground] m-auto text-center items-center">
      <p className="text-xl">{name}</p>
      <a
        href={`https://cdn.nhcarrigan.com/certifications/${fileName}`}
        rel="noreferrer"
        target="_blank"
      >
        <Image
          alt={name}
          className="m-auto"
          height={250}
          src={`https://cdn.nhcarrigan.com/certifications/${fileName}`}
          width={250}
        />
      </a>
      <p>{issuer}</p>
      <p>
        {date.toLocaleDateString("en-GB", {
          month: "long",
          year:  "numeric",
        })}
      </p>
    </div>
  );
};
