/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import Image from "next/image";
import type { JSX } from "react";

interface CharacterProperties {
  readonly id:       string;
  readonly onClick?: ()=> void;
  readonly focused:  boolean;
}

/**
 * Renders the view for a legacy character.
 * @param properties - The character to render.
 * @returns A JSX element.
 */
export const CharacterComponent = (
  properties: CharacterProperties,
): JSX.Element => {
  const { id, onClick, focused } = properties;

  return focused
    ? <div style={{ position: "relative" }}>
      <Image
        alt={id}
        className="m-h-[525px] m-w-[400px] object-contain"
        height={525}
        onClick={onClick}
        src={`https://cdn.nhcarrigan.com/characters/${id}.png`}
        width={400}
      />
      <div
        aria-hidden="true"
        className="absolute h-full w-full m-h-[525px] m-w-[400px]"
        style={{ border: "5px solid yellow", left: 0, top: 0, zIndex: 1 }}
      ></div>
    </div>
    : <Image
      alt={id}
      className="m-h-[525px] m-w-[400px] object-contain"
      height={525}
      onClick={onClick}
      src={`https://cdn.nhcarrigan.com/characters/${id}.png`}
      width={400}
    />;
};
