/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */

/**
 * List of professional work to render.
 */
export const Jobs: Array<{
  title:   string;
  company: string;

  /**
   * Set ALL dates to the 5th. These are not exact days, but intended to avoid month discrepancies
   * when dealing with timezones.
   */
  start: Date;

  /**
   * Set ALL dates to the 5th. These are not exact days, but intended to avoid month discrepancies
   * when dealing with timezones.
   */
  end:         Date | null;
  link:        string;
  type:        "volunteer" | "fixed" | "project" | "hypothetical";
  description: string;

  /**
   * File name of logo.
   */
  logo: string;
}> = [
  {
    company:     "Your Company!",
    description: `You could be our next client! Hit the "Contact" link and use the "Hire Us" button to get in touch!`,
    end:         null,
    link:        "https://topmate.io/nhcarrigan/913920",
    logo:        "future.jpeg",
    start:       new Date(Date.now()),
    title:       "Consultant",
    type:        "hypothetical",
  },
  {
    company: "nhcarrigan",
    description:
      "Began my journey learning to code, starting from the top of the freeCodeCamp curriculum.",
    end:   null,
    link:  "https://naomi.lgbt",
    logo:  "nhcarrigan.jpeg",
    start: new Date("April 5 2020"),
    title: "Started Journey",
    type:  "hypothetical",
  },
  {
    company:     "Artists For Palestine",
    description: `As a Development Lead at Art 4 Palestine, I developed a bot that efficiently manages integrations between Airtable forms, Trello boards, and Discord, streamlining workflow and improving productivity. The bot also pulls news articles from reputable sources and cross-posts them into the server, keeping the community informed with reliable updates.

Additionally, I guided and mentored other developers in the design and coding of the website, ensuring high-quality output and consistent alignment with project goals. My contributions have been instrumental in supporting the organization's initiatives and fostering collaboration within the development team.`,
    end:   null,
    link:  "https://art4palestine.org",
    logo:  "a4p.jpeg",
    start: new Date("November 5 2023"),
    title: "Development Lead",
    type:  "volunteer",
  },
  {
    company:     "AngelRose",
    description: `As a Discord Moderator at AngelRose, I played a key role in maintaining a safe, respectful, and engaging environment for community members. I monitored conversations, enforcing community guidelines to prevent disruptive behavior and protect users. Additionally, I addressed and resolved conflicts, providing support and guidance to members to promote a positive experience. My contributions helped uphold the integrity of the community and foster an inclusive and welcoming space for all participants.`,
    end:         null,
    link:        "https://discord.gg/kYpjgEB",
    logo:        "angel.png",
    start:       new Date("September 5 2023"),
    title:       "Community Moderator",
    type:        "volunteer",
  },
  {
    company:     "Deepgram",
    description: `<div class="pl-4">
      <p>As a Discord Bot Developer, I spearheaded the creation and implementation of an advanced bot designed to revolutionize community management and user interactions. My primary focus involved developing a comprehensive suite of features to streamline communication, enhance user engagement, and provide valuable insights into community health.</p>

      <p>Leveraging AI capabilities, I integrated intelligent automation to address user queries efficiently and maintain an organized community structure. Additionally, I implemented cross-platform integration features to ensure seamless information flow between Discord, GitHub, and ProductBoard, fostering a cohesive ecosystem for community management.</p>

      <p>Through this multifaceted approach, I significantly improved community interactions, user satisfaction, and the overall efficiency of community management processes.</p>

      <p>Key responsibilities and achievements include:</p>
      <ul class="list-none">
        <li class="mb-2 relative before:content-['🩵']">Message Management and Organization:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Developed functionality to relocate messages from standard channels to forum channels</li>
            <li class="mb-2 relative before:content-['🩷']">Implemented a scheduled messaging system to guide users towards appropriate channels</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">AI-Powered Assistance:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Integrated AI capabilities for automatic question answering in forum channels</li>
            <li class="mb-2 relative before:content-['🩷']">Designed feature for marking responses as correct answers</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Community Engagement Tools:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Developed daily and weekly aggregations of unanswered questions</li>
            <li class="mb-2 relative before:content-['🩷']">Implemented a reminder system for inactive questions after seven days</li>
            <li class="mb-2 relative before:content-['🩷']">Created cross-posting functionality to GitHub discussion board for answered questions</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Metrics and Analytics:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Developed tracking system for community health indicators including unanswered, answered, and closed questions</li>
            <li class="mb-2 relative before:content-['🩷']">Created a dashboard for easy monitoring of community engagement</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Cross-Platform Integration:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Implemented feature to post feedback messages to ProductBoard</li>
            <li class="mb-2 relative before:content-['🩷']">Designed system for cross-posting between Discord and GitHub</li>
          </ul>
        </li>
      </ul>
    </div>`,
    end:   new Date("June 5 2024"),
    link:  "https://deepgram.com",
    logo:  "deepgram.jpeg",
    start: new Date("July 5 2023"),
    title: "Community Bot Engineer",
    type:  "project",
  },
  {
    company:     "BigBadBeaver Productions",
    description: `<div class="pl-4">
      <p>As a Twitch Bot Developer, I spearheaded the creation and deployment of "PrivateTwigs," a custom chat bot designed to revolutionize stream management and viewer engagement. My role involved engineering sophisticated features, implementing data analysis tools, and creating user-friendly interfaces to empower streamers with valuable insights and enhanced interaction capabilities.</p>

      <p>By developing a comprehensive logging system and custom redemption rewards, I significantly improved the streaming experience for both content creators and viewers. My work directly contributed to increased viewer engagement and provided streamers with powerful tools to manage and grow their channels effectively.</p>

      <p>Through close collaboration with streamers and careful attention to Twitch's guidelines, I ensured that PrivateTwigs not only met but exceeded user expectations while maintaining full compliance with platform regulations.</p>

      <p>Key responsibilities and achievements include:</p>
      <ul class="list-none">
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">PrivateTwigs Bot Development:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Engineered and deployed a custom Twitch chat bot, enhancing stream management and viewer engagement</li>
            <li class="mb-2 relative before:content-['🩷']">Developed comprehensive logging functionality for all chat messages and stream events</li>
            <li class="mb-2 relative before:content-['🩷']">Implemented data analysis tools to derive strategic insights from stream data</li>
            <li class="mb-2 relative before:content-['🩷']">Created a user-friendly interface for streamers to access and utilize collected data</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Custom Redemption Rewards System:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Designed and implemented a custom redemption rewards system within the bot</li>
            <li class="mb-2 relative before:content-['🩷']">Enabled unique viewer interactions, increasing overall stream engagement</li>
            <li class="mb-2 relative before:content-['🩷']">Developed a flexible framework allowing streamers to easily create and modify rewards</li>
            <li class="mb-2 relative before:content-['🩷']">Integrated reward system with Twitch's API to ensure seamless operation</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Performance Optimization and Compliance:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Optimized bot performance to handle high-traffic streams without latency</li>
            <li class="mb-2 relative before:content-['🩷']">Ensured compliance with Twitch's terms of service and API guidelines</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Continuous Improvement and Collaboration:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Collaborated with streamers to gather feedback and iteratively improve bot features</li>
            <li class="mb-2 relative before:content-['🩷']">Regularly updated and refined bot functionality based on user needs and platform changes</li>
          </ul>
        </li>
      </ul>
    </div>`,
    end:   new Date("January 5 2024"),
    link:  "https://linktr.ee/bigbadbeaver",
    logo:  "beaver.png",
    start: new Date("May 5 2023"),
    title: "Twitch Integration Engineer",
    type:  "project",
  },
  {
    company:     "Sema Software",
    description: `<div class="pl-4">
      <p>As an Open Source Community Manager, I successfully spearheaded the growth of our Discord community from 300 to 1,000 members, achieving a remarkable 233% increase. My role involved implementing strategic engagement initiatives, creating an inclusive environment, and leading multiple open source projects that significantly enhanced developer productivity and community engagement.</p>

      <p>By developing standardized tools and resources, such as project templates and skills assessment bots, I streamlined processes and improved consistency across the organization. My work on the Developer Skills Matrix ecosystem, including the creation of dedicated bots and websites, facilitated self-assessment and skill development among community members.</p>

      <p>Through the engineering of specialized Discord bots and the cultivation of a vibrant community atmosphere, I increased the visibility of open source opportunities and drove higher levels of member participation and retention. My efforts in cross-functional collaboration ensured that community initiatives aligned with broader business objectives, contributing to both user growth and product adoption.</p>

      <p>Key responsibilities and achievements include:</p>
      <ul class="list-none">
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Community Growth and Engagement:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Spearheaded growth of Discord community from 300 to 1,000 members, representing a 233% increase</li>
            <li class="mb-2 relative before:content-['🩷']">Implemented strategic engagement initiatives and created an inclusive environment</li>
            <li class="mb-2 relative before:content-['🩷']">Cultivated a vibrant, engaging community atmosphere, resulting in increased member participation and retention</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Open Source Initiatives Leadership:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Led multiple open source initiatives, enhancing developer productivity and community engagement</li>
            <li class="mb-2 relative before:content-['🩷']">Developed and implemented a standardized base template for new projects, streamlining project initiation and improving consistency</li>
            <li class="mb-2 relative before:content-['🩷']">Engineered a Discord bot to query and showcase projects from the Open Source Welcoming Committee, increasing visibility of opportunities</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Developer Skills Matrix Ecosystem Management:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Created and maintained a Discord bot for self-assessments</li>
            <li class="mb-2 relative before:content-['🩷']">Developed a dedicated website for the Skills Matrix</li>
            <li class="mb-2 relative before:content-['🩷']">Implemented a Slack bot to extend accessibility across platforms</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Strategic Alignment and Collaboration:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Collaborated cross-functionally to align community initiatives with overall business objectives</li>
            <li class="mb-2 relative before:content-['🩷']">Drove both user growth and product adoption through strategic community management</li>
          </ul>
        </li>
      </ul>
    </div>`,
    end:   new Date("September 5 2022"),
    link:  "https://www.semasoftware.com",
    logo:  "sema.jpeg",
    start: new Date("May 5 2022"),
    title: "Community Manager and Open-Source Engineer",
    type:  "fixed",
  },
  {
    company:     "4C",
    description: `<div class="pl-4">
      <p>As a Discord Community Growth Manager, I successfully orchestrated the exponential growth of our Discord community, expanding it from 1,100 to 3,350 members – a remarkable 205% increase. My role encompassed implementing strategic engagement initiatives, developing community events, and creating a safe, inclusive environment that fostered active participation and meaningful interactions among members.</p>

      <p>By implementing a comprehensive onboarding process and establishing clear community guidelines, I ensured new members were effectively integrated and all participants felt welcome and secure. My data-driven approach, involving the analysis of community metrics and user feedback, allowed for continuous improvement of engagement strategies and overall member satisfaction.</p>

      <p>Through close collaboration with cross-functional teams, I aligned community initiatives with broader business objectives, ensuring that our thriving Discord community contributed significantly to our organization's goals. My proactive conflict resolution and attentive addressing of member concerns maintained a positive community atmosphere, crucial for sustained growth and engagement.</p>

      <p>Key responsibilities and achievements include:</p>
      <ul class="list-none">
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Community Growth and Engagement:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Orchestrated exponential growth of Discord community from 1,100 to 3,350 members, representing a 205% increase</li>
            <li class="mb-2 relative before:content-['🩷']">Implemented strategic engagement initiatives to foster an active and thriving community space</li>
            <li class="mb-2 relative before:content-['🩷']">Developed and executed community events, driving participation and member retention</li>
            <li class="mb-2 relative before:content-['🩷']">Created and moderated discussion channels to encourage meaningful interactions</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Community Management and Moderation:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Implemented a comprehensive onboarding process for new members, enhancing their integration into the community</li>
            <li class="mb-2 relative before:content-['🩷']">Established and enforced community guidelines, ensuring a safe and inclusive environment for all members</li>
            <li class="mb-2 relative before:content-['🩷']">Managed conflict resolution and addressed member concerns, maintaining a positive community atmosphere</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Data-Driven Strategy and Collaboration:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Analysed community metrics and user feedback to continually improve engagement strategies and member satisfaction</li>
            <li class="mb-2 relative before:content-['🩷']">Collaborated with cross-functional teams to align community initiatives with broader business objectives</li>
          </ul>
        </li>
      </ul>
    </div>`,
    end:   new Date("November 5 2022"),
    link:  "https://discord.com/invite/ns5x8bTz25",
    logo:  "4c.png",
    start: new Date("May 5 2022"),
    title: "Community Manager",
    type:  "fixed",
  },
  {
    company:     "TweetShift",
    description: `<div class="pl-4">
      <p>As the Community Manager, I successfully managed and supported a vast user community spanning over 230,000 Discord servers, demonstrating my ability to operate effectively at scale. My role encompassed providing comprehensive support, implementing and enforcing community guidelines, and fostering high levels of engagement across this extensive user base.</p>

      <p>By delivering high-quality support and creating robust self-service resources, I ensured optimal bot functionality and maintained high levels of user satisfaction. My proactive approach to community management, including the development and execution of strategies to prevent and mitigate issues, contributed to maintaining a safe and inclusive environment for all members.</p>

      <p>Through organizing community events, creating informative content, and recognizing active contributors, I fostered a vibrant and engaged community. My work directly contributed to the growth, stability, and positive culture of this large-scale Discord ecosystem.</p>

      <p>Key responsibilities and achievements include:</p>
      <ul class="list-none">
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Large-Scale Community Management:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Managed and supported a vast user community spanning over 230,000 Discord servers</li>
            <li class="mb-2 relative before:content-['🩷']">Demonstrated ability to operate effectively at scale, maintaining high standards across a large user base</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Comprehensive User Support:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Provided high-quality support to users, ensuring optimal bot functionality and user satisfaction</li>
            <li class="mb-2 relative before:content-['🩷']">Responded to user inquiries and troubleshooting requests in a timely and effective manner</li>
            <li class="mb-2 relative before:content-['🩷']">Created and maintained user guides and FAQs to empower self-service problem-solving</li>
            <li class="mb-2 relative before:content-['🩷']">Collaborated with the development team to relay user feedback and suggest improvements</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Community Guidelines and Moderation:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Implemented and enforced community guidelines to maintain a safe and inclusive environment</li>
            <li class="mb-2 relative before:content-['🩷']">Moderated discussions and user-generated content across multiple channels</li>
            <li class="mb-2 relative before:content-['🩷']">Resolved conflicts and addressed user concerns promptly and professionally</li>
            <li class="mb-2 relative before:content-['🩷']">Developed and executed strategies to prevent and mitigate potential community issues</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Community Engagement Initiatives:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Organized and facilitated community events and discussions</li>
            <li class="mb-2 relative before:content-['🩷']">Created and curated content to keep users informed about updates and best practices</li>
            <li class="mb-2 relative before:content-['🩷']">Recognized and rewarded active and helpful community members</li>
          </ul>
        </li>
      </ul>
    </div>`,
    end:   new Date("May 5 2023"),
    link:  "https://tweetshift.com",
    logo:  "tweetshift.png",
    start: new Date("January 5 2022"),
    title: "Community Manager",
    type:  "fixed",
  },
  {
    company:     "Rythm",
    description: `<div class="pl-4">
      <p>As a Discord Community Manager specializing in bot development, I spearheaded the creation and implementation of advanced management tools for a thriving community of over 300,000 members. My primary focus involved developing a comprehensive suite of bots and systems to streamline moderation, enhance user engagement, and provide valuable insights into community health and staff performance.</p>

      <p>Leveraging my expertise in Discord bot development, I implemented robust automoderation systems, designed engaging economy features, and created powerful analytics tools. My work significantly improved community interactions, user satisfaction, and the overall efficiency of community management processes.</p>

      <p>Through this multifaceted approach, I fostered a more engaging, secure, and well-managed community environment, contributing to its substantial growth and user retention.</p>

      <p>Key responsibilities and achievements include:</p>
      <ul class="list-none">
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Comprehensive Moderation Bot:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Implemented robust automoderation system with customizable rules</li>
            <li class="mb-2 relative before:content-['🩷']">Developed extensive moderation history tracking and individual case management</li>
            <li class="mb-2 relative before:content-['🩷']">Created evidence logging system and staff-only note functionality</li>
            <li class="mb-2 relative before:content-['🩷']">Integrated FAQ response system for efficient community support</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Economy and Engagement Bot:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Designed leveling system to reward long-term activity</li>
            <li class="mb-2 relative before:content-['🩷']">Implemented role-based rewards and currency system</li>
            <li class="mb-2 relative before:content-['🩷']">Created customisable user profiles and badge earning mechanism</li>
            <li class="mb-2 relative before:content-['🩷']">Developed specialised reward purchasing system</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Staff Management and Analytics Tools:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Built staff incentive bot for recognising exceptional contributions</li>
            <li class="mb-2 relative before:content-['🩷']">Developed staff analytics bot tracking performance metrics (commands used, messages sent, modmail threads closed)</li>
            <li class="mb-2 relative before:content-['🩷']">Implemented leadership tools for volunteer moderator management</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Community Engagement Tools:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Created analytics bot for monitoring user engagement</li>
            <li class="mb-2 relative before:content-['🩷']">Developed music-themed trivia bot for community entertainment</li>
            <li class="mb-2 relative before:content-['🩷']">Built cross-platform social media bot for Twitter-Discord-Slack integration</li>
          </ul>
        </li>
      </ul>
    </div>`,
    end:   new Date("November 5, 2024"),
    link:  "https://rythm.fm",
    logo:  "rythm.jpeg",
    start: new Date("April 5 2022"),
    title: "Senior Integrations Engineer",
    type:  "fixed",
  },
  {
    company:     "Streamcord",
    description: `<div class="pl-4">
      <p>As a Community Manager, I played a pivotal role in nurturing and expanding a vibrant community of over 50,000 members. My responsibilities encompassed a wide range of areas, including community engagement, technical support, human resources management, and bot operations. I was instrumental in fostering a thriving ecosystem around the Streamcord bot, which is utilized by over 1 million communities.</p>

      <p>My multifaceted approach involved implementing innovative engagement strategies, contributing to technical infrastructure, spearheading human resources initiatives, and ensuring seamless bot operations. Through these efforts, I significantly enhanced member retention, activity levels, and overall user satisfaction.</p>

      <p>By bridging the gap between the user community and the development team, I facilitated continuous improvement of the Streamcord bot and associated services, directly contributing to its widespread adoption and success.</p>

      <p>Key responsibilities and achievements include:</p>
      <ul class="list-none">
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Community Management and Growth:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Managed and nurtured a thriving community of 50,000+ members</li>
            <li class="mb-2 relative before:content-['🩷']">Provided comprehensive support for the Streamcord bot, utilized by over 1 million communities</li>
            <li class="mb-2 relative before:content-['🩷']">Implemented engagement strategies, including staff streams and game nights, to foster community interaction</li>
            <li class="mb-2 relative before:content-['🩷']">Led a complete community overhaul, significantly boosting member retention and activity</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Technical Infrastructure and Development:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Supported the development process for the Streamcord bot</li>
            <li class="mb-2 relative before:content-['🩷']">Maintained and updated documentation to ensure clarity and accessibility</li>
            <li class="mb-2 relative before:content-['🩷']">Collaborated on the development and maintenance of the dashboard site</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Human Resources Initiatives:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Conducted interviews and managed the onboarding process for new staff members</li>
            <li class="mb-2 relative before:content-['🩷']">Developed and delivered comprehensive training programs for team members</li>
            <li class="mb-2 relative before:content-['🩷']">Implemented and conducted quarterly staff evaluations to ensure team performance and growth</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Bot Operations and User Support:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Addressed user queries and troubleshooting requests promptly</li>
            <li class="mb-2 relative before:content-['🩷']">Collaborated with the development team to implement user feedback and feature requests</li>
            <li class="mb-2 relative before:content-['🩷']">Monitored bot performance across millions of communities to maintain high uptime and user satisfaction</li>
          </ul>
        </li>
      </ul>
    </div>`,
    end:   new Date("December 5 2024"),
    link:  "https://streamcord.io",
    logo:  "streamcord.jpeg",
    start: new Date("August 5 2021"),
    title: "Community Manager and Infrastructure Engineer",
    type:  "fixed",
  },
  {
    company:     "Battlesnake",
    description: `As a Community Moderator at Battlesnake, I played a vital role in ensuring a safe and welcoming environment for players. My focus was on promoting a positive experience for all members, allowing them to enjoy the game and interact with one another respectfully.

Additionally, I contributed to driving engagement for the Summer League 2021 and the Caster House system, fostering enthusiasm and participation in these events. My efforts helped create an inclusive and vibrant community for Battlesnake enthusiasts.`,
    end:   new Date("November 5 2022"),
    link:  "https://play.battlesnake.com",
    logo:  "battlesnake.jpeg",
    start: new Date("June 5 2021"),
    title: "Community Moderator",
    type:  "volunteer",
  },
  {
    company:     "Caylus Crew",
    description: `As the Discord Administrator and Platform Engineering Manager at Caylus Crew, I developed custom bots that enhanced the community experience and streamlined operations. One such bot posted daily messages wishing happy birthday to members, fostering a sense of connection and camaraderie. I also created a bot to manage sponsor perks, ensuring efficient and accurate distribution of benefits to eligible members.

In addition to technical contributions, I coached and trained moderators, providing quarterly staff reviews to support their professional growth and improve performance. My work played a pivotal role in maintaining a vibrant, well-managed community and ensuring an exceptional experience for all participants.`,
    end:   null,
    link:  "https://discord.gg/infinite",
    logo:  "caylus.png",
    start: new Date("June 5 2021"),
    title: "Discord Administrator and Platform Engineering Manager",
    type:  "volunteer",
  },
  {
    company:     "Xcentric Collective",
    description: `As an Integrations Engineer at Xcentric Collective, I developed a custom Discord bot that incorporated a unique Matchmaking Rating (MMR) system to calculate Rocket League proficiency. This system enabled users to track and monitor their skill levels accurately.

The bot also featured the ability to define teams and find matches with opponents of similar skill levels, facilitating balanced and fair gameplay. Additionally, the bot allowed users to schedule matches seamlessly, providing a streamlined and efficient experience for the community. My work enhanced the overall gaming experience and engagement within the Xcentric Collective community. As an Integrations Engineer at Xcentric Collective, I developed a custom Discord bot that incorporated a unique Matchmaking Rating (MMR) system to calculate Rocket League proficiency. This system enabled users to track and monitor their skill levels accurately. The bot also featured the ability to define teams and find matches with opponents of similar skill levels, facilitating balanced and fair gameplay. Additionally, the bot allowed users to schedule matches seamlessly, providing a streamlined and efficient experience for the community. My work enhanced the overall gaming experience and engagement within the Xcentric Collective community.`,
    end:   new Date("July 5 2023"),
    link:  "http://discord.gg/U3jQVYNbJt",
    logo:  "xcentric.jpg",
    start: new Date("April 5 2021"),
    title: "Integrations Engineer",
    type:  "volunteer",
  },
  {
    company:     "DigitalOcean",
    description: `As a Hacktoberfest Community Moderator at DigitalOcean, I supported the community by building a custom bot to ensure repository links were correctly included in promotional channel messages, streamlining interactions, and providing automated responses for frequently asked questions. This contributed to a smoother experience for participants and enhanced community engagement.

In addition to managing the bot, I answered queries and guided developers in their open-source contributions, helping them navigate the Hacktoberfest event and maximize their impact. By maintaining a safe and welcoming community space, I fostered an inclusive environment for developers of all skill levels to collaborate and grow. My efforts played a crucial role in the success of the event and the satisfaction of its participants.`,
    end:   new Date("November 5 2024"),
    link:  "https://hacktoberfest.com",
    logo:  "digitalocean.jpeg",
    start: new Date("April 5 2021"),
    title: "Hacktoberfest Community Moderator",
    type:  "volunteer",
  },
  {
    company:     "EddieHub",
    description: `As a Discord Administrator for EddieHub, I played a key role in moderating the community and fostering an open and inclusive environment. My focus was on upholding community guidelines and ensuring a positive experience for all members.

I provided support and encouragement to members on their development path, offering guidance and resources to help them grow and succeed. Additionally, I planned and managed community events and initiatives, creating opportunities for members to engage, learn, and collaborate.

My efforts contributed to the vibrancy and success of the EddieHub community, helping to create a welcoming space for developers to thrive.`,
    end:   new Date("May 5 2023"),
    link:  "https://www.eddiehub.org",
    logo:  "eddiehub.jpeg",
    start: new Date("January 5 2021"),
    title: "Discord Administrator",
    type:  "volunteer",
  },
  {
    company:     "Commit Your Code",
    description: `As the Discord Administrator and Lead Integrations Engineer at Commit Your Code, I played a key role in fostering a supportive and friendly community environment by moderating interactions and ensuring a positive space for members. I provided guidance to individuals on their development path, offering support as they prepared for their first job or encountered coding challenges.

To enhance community security, I built a robust verification system that significantly reduced the number of compromised accounts, safeguarding members' data and promoting a safe space for collaboration. My contributions have been instrumental in supporting members' growth and maintaining a secure, welcoming atmosphere within the community.`,
    end:   null,
    link:  "https://discord.gg/StwJYeq",
    logo:  "cyc.jpeg",
    start: new Date("December 5 2020"),
    title: "Discord Administrator and Lead Integrations Engineer",
    type:  "volunteer",
  },
  {
    company:     "freeCodeCamp",
    description: `<div class="pl-4">
      <p>As a Community Manager at freeCodeCamp, I played a crucial role in maintaining and enhancing an open-source curriculum used by millions of developers worldwide. My responsibilities encompassed curriculum development, technical solution implementation, community management across multiple platforms, and contributing to the overall growth of the freeCodeCamp ecosystem.</p>

      <p>By leading curriculum redesigns, developing technical solutions, and fostering vibrant online communities, I significantly improved user engagement, accessibility, and the overall learning experience for developers at all levels. My work directly contributed to the expansion and success of freeCodeCamp's mission to provide free coding education to anyone, anywhere.</p>

      <p>Through collaborative efforts with a global team of contributors and strategic alignment with organizational goals, I helped shape freeCodeCamp's direction and impact in the world of coding education.</p>

      <p>Key responsibilities and achievements include:</p>
      <ul class="list-none">
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Curriculum Development and Enhancement:
          <ul class="pl-4 mt-2 list-none">
            <li class="mb-2 relative before:content-['🩷']">Led complete redesign of Responsive Web Design curriculum, improving accessibility and user engagement</li>
            <li class="mb-2 relative before:content-['🩷']">Collaborated with global team of contributors to ensure curriculum relevance and quality</li>
            <li class="mb-2 relative before:content-['🩷']">Implemented user feedback to continuously improve learning materials</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Technical Solutions Development:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Built and deployed a moderation bot for Discord, significantly improving community safety and functionality</li>
            <li class="mb-2 relative before:content-['🩷']">Created an efficient tool for distributing weekly email newsletter to millions of subscribers</li>
            <li class="mb-2 relative before:content-['🩷']">Optimized community management processes across Discord, Forum, and Reddit platforms</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Community Management and Engagement:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Provided guidance and support to users on their web development journey</li>
            <li class="mb-2 relative before:content-['🩷']">Implemented engagement strategies resulting in increased user participation and retention</li>
            <li class="mb-2 relative before:content-['🩷']">Fostered a welcoming and inclusive environment for learners of all levels</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Strategic Growth and Representation:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Collaborated with leadership to align community initiatives with organizational goals</li>
            <li class="mb-2 relative before:content-['🩷']">Analyzed user data and feedback to inform strategic decisions</li>
            <li class="mb-2 relative before:content-['🩷']">Represented freeCodeCamp in external events and collaborations</li>
          </ul>
        </li>
      </ul>
    </div>`,
    end:   null,
    link:  "https://freecodecamp.org",
    logo:  "fcc.jpeg",
    start: new Date("December 5, 2020"),
    title: "Educational Developer and Community Manager",
    type:  "fixed",
  },
  {
    company:     "Virtual Insanity",
    description: `As a Discord Moderator for Virtual Insanity, an adult-only community, I was instrumental in cultivating a secure, respectful, and interactive atmosphere for our diverse members. My responsibilities encompassed vigilant monitoring of discussions, ensuring compliance with established guidelines to deter any disruptive conduct, and safeguarding our users. Alongside conflict resolution, I provided empathetic support and guidance, fostering a harmonious environment conducive to positive interactions. Moreover, I actively assisted in verifying identification documents, reinforcing our commitment to maintaining a safe and authentic community experience. Through these efforts, I contributed to upholding the community's integrity and nurturing an inclusive space for all participants to thrive.`,
    end:         null,
    link:        "https://discord.com/invite/GDYNGnrGUs",
    logo:        "troopy.png",
    start:       new Date("May 5 2024"),
    title:       "Discord Moderator",
    type:        "volunteer",
  },
  {
    company:     "Azuliah (VTuber)",
    description: `As a Discord Administrator and Integrations Engineer at Azuliah, I established custom integrations to streamline moderation efforts and enhance community management. These integrations supported the moderation team in maintaining a safe and welcoming space for all members.

In addition to technical contributions, I trained the owner and moderation team on best practices for running a successful community. My guidance included techniques for efficient moderation, conflict resolution, and fostering positive interactions among members. Through my efforts, I played a key role in ensuring the community's smooth operation and promoting a vibrant, supportive environment.`,
    end:   new Date("April 5 2024"),
    link:  "https://discord.com/invite/XNSy8PMvyy",
    logo:  "azuliah.jpg",
    start: new Date("December 5 2023"),
    title: "Discord Administrator and Integrations Engineer",
    type:  "volunteer",
  },
  {
    company:     "Rion Kuroko (VTuber)",
    description: `As a Discord Moderator for Rion Kuroko, I constructed the server almost entirely from scratch to tailor it to the specific needs of the community. This involved designing and implementing structures, channels, and rules that supported a smooth and organized environment.

I also provided guidance to the owner on the technical aspects of Discord moderation, sharing best practices and offering solutions to effectively manage the server. My efforts played a key role in establishing a functional, user-friendly community space and empowering the owner with the knowledge needed to maintain and grow the server.`,
    end:   new Date("Jan 5 2024"),
    link:  "https://discord.com",
    logo:  "rion.jpg",
    start: new Date("Nov 5 2023"),
    title: "Discord Moderator",
    type:  "volunteer",
  },
  {
    company:     "Rythm",
    description: `As a Senior Discord Moderator for Rythm, I played a dual role in overseeing community moderation and mentoring the moderation team. My responsibilities included tracking weekly staff activity to monitor performance and identify areas for improvement, ensuring the team remained effective and engaged.

Additionally, I guided and supported moderators, helping them develop their skills and excel in their roles. By identifying opportunities to enhance staff activity, I contributed to the overall health and vibrancy of the community. My efforts were instrumental in maintaining a positive, safe, and well-managed space for all members.`,
    end:   new Date("July 5 2022"),
    link:  "https://discord.com/invite/rythm",
    logo:  "rythm.jpeg",
    start: new Date("Feb 5 2022"),
    title: "Senior Discord Moderator",
    type:  "volunteer",
  },
  {
    company:     "TweetShift",
    description: `As Technical Support Staff for TweetShift, I responded promptly to user queries, addressing issues and bugs within the bot to ensure a smooth user experience. I provided clear guidance on how to use the bot's features effectively, helping users maximize its capabilities.

My role involved troubleshooting technical challenges and offering solutions to enhance user satisfaction. By delivering efficient support and sharing helpful tips, I contributed to the overall success and reliability of the bot for the TweetShift community.`,
    end:   new Date("Jan 5 2022"),
    link:  "https://discord.com/invite/zdfQhjc",
    logo:  "tweetshift.png",
    start: new Date("Oct 5 2021"),
    title: "Technical Support Staff",
    type:  "volunteer",
  },
  {
    company:     "Rythm",
    description: `As a Discord Moderator for Rythm, I played a central role in maintaining a safe, respectful, and welcoming environment for community members. I monitored conversations to ensure compliance with community guidelines and addressed any disruptive behavior promptly.

My efforts helped foster a positive and inclusive space for all members, contributing to the overall health and vibrancy of the Rythm community.`,
    end:   new Date("Feb 5 2022"),
    link:  "https://discord.com/invite/rythm",
    logo:  "rythm.jpeg",
    start: new Date("Sept 5 2021"),
    title: "Discord Moderator",
    type:  "volunteer",
  },
  {
    company:     "Streamcord",
    description: `As Technical Support Staff for Streamcord, I provided essential support to users by triaging and debugging issues related to the Streamcord Discord bot. My role involved investigating and resolving technical challenges to ensure a seamless user experience.

Acting as a liaison between users and developers, I facilitated clear communication and reported user feedback to the development team for continuous improvement. Additionally, I moderated and engaged with the community, fostering a positive and inclusive environment for all participants. My efforts contributed to the overall success and satisfaction of the Streamcord community.`,
    end:   new Date("Aug 5 2021"),
    link:  "https://discord.com/invite/streamcord",
    logo:  "streamcord.jpeg",
    start: new Date("Mar 5 2021"),
    title: "Technical Support Staff",
    type:  "volunteer",
  },
  {
    company:     "freeCodeCamp",
    description: `As a Community Moderator for freeCodeCamp, I provided vital support to users (campers) as they navigated the freeCodeCamp curriculum. My role included assisting users in debugging their code and answering questions, ensuring they received the guidance they needed to progress in their learning journey.

I engaged with and moderated the community on the forum and Discord server, fostering a positive, supportive, and inclusive environment for all members. Additionally, I assisted with issue triage and pull request review on GitHub, contributing to the ongoing improvement and development of freeCodeCamp's open-source projects. My efforts played a key role in maintaining the quality of the community and empowering users to achieve their learning goals.`,
    end:   new Date("Dec 5 2020"),
    link:  "https://discord.com/invite/freecodecamp-org-official-fi-fo-692816967895220344",
    logo:  "fcc.jpeg",
    start: new Date("Jun 5 2020"),
    title: "Community Moderator",
    type:  "volunteer",
  },
  {
    company:     "FruitPursuits",
    description: `As a Discord Moderator for FruitPursuits, I provide crucial support to members, ensuring they have a seamless experience within our community. I troubleshoot technical issues, enforce community guidelines, and foster engagement among members. Collaborating with fellow moderators, I contribute to the ongoing improvement of our Discord server, empowering users to fully enjoy their fruit-loving journey.`,
    end:         null,
    link:        "https://discord.gg/xcy2fRsC5K",
    logo:        "fruit.png",
    start:       new Date("March 5 2024"),
    title:       "Community Moderator",
    type:        "volunteer",
  },
  {
    company:     "Deepgram",
    description: `
    <div class="pl-4">
      <p>As a DX Consultant at Deepgram, I spearhead efforts to enhance community engagement and streamline developer experiences. Leveraging my expertise, I optimize community management workflows on platforms like Slack, GitHub Discussions, and Discord. My primary focus involves acting as a Community Manager, where I strive to answer approximately 60% of community inquiries, foster engagement, and ensure valuable feedback reaches the Product Board for consideration.</p>

      <p>In parallel, I lead DX initiatives, delivering minor documentation improvements, documenting new product features, and integrating new solutions. My proficiency extends to SDK support (JS, Python), where I deliver enhancements and develop new applications as needed. Additionally, I provide high-priority support for demo applications.</p>

      <p>Through my multifaceted approach, I drive tangible improvements in community interactions and developer experiences, contributing to Deepgram's growth and user satisfaction.</p>

      <p>Key responsibilities and achievements include:</p>
      <ul class="list-none">
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Community Management:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Provide community support across Slack, GitHub Discussions, and Discord</li>
            <li class="mb-2 relative before:content-['🩷']">Address approximately 60% of community inquiries, ensuring prompt and accurate responses</li>
            <li class="mb-2 relative before:content-['🩷']">Foster community engagement through proactive interactions and targeted initiatives</li>
            <li class="mb-2 relative before:content-['🩷']">Facilitate feedback flow to Product Board, driving user-centric product improvements</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Developer Experience (DX) Initiatives:
          <ul class=" pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Spearhead documentation improvements, enhancing clarity and accessibility</li>
            <li class="mb-2 relative before:content-['🩷']">Integrate innovative solutions to streamline developer workflows</li>
            <li class="mb-2 relative before:content-['🩷']">Deliver high-priority support for demo applications, showcasing product capabilities</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">SDK Support and Development:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Provide expert support for JavaScript and Python SDKs</li>
            <li class="mb-2 relative before:content-['🩷']">Implement enhancements to existing SDKs based on developer feedback and emerging needs</li>
            <li class="mb-2 relative before:content-['🩷']">Develop new applications leveraging Deepgram's SDKs to demonstrate best practices</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵']">Workflow Optimization:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Streamline community management processes across multiple platforms</li>
            <li class="mb-2 relative before:content-['🩷']">Implement efficient systems for tracking and addressing developer inquiries</li>
            <li class="mb-2 relative before:content-['🩷']">Optimize feedback collection and integration into product development cycle</li>
          </ul>
        </li>
      </ul>
    </div>`,
    end:   null,
    link:  "https://deepgram.com",
    logo:  "deepgram.jpeg",
    start: new Date("June 5 2024"),
    title: "Developer Experience Consultant",
    type:  "fixed",
  },
  {
    company:     "Safeway",
    description: `<div class="pl-4">
      <p>As the Service Operations Manager at Safeway, I played a pivotal role in overseeing the store's day-to-day operations and maintaining exceptional service standards. My responsibilities encompassed a wide range of critical functions, from personnel management and training to ensuring compliance with safety regulations and company policies.</p>

      <p>By focusing on hiring, onboarding, and mentoring both new associates and management personnel, I fostered a skilled and motivated workforce capable of delivering high-quality service. My implementation of comprehensive safety programs and strict adherence to OSHA regulations created a secure environment for both employees and customers.</p>

      <p>Through diligent auditing of financial records and assistance with payroll processing, I contributed to the store's financial accuracy and operational efficiency. My collaborative approach to problem-solving and commitment to enforcing company standards helped maintain a positive work environment and uphold Safeway's reputation for excellence in service.</p>

      <p>Key responsibilities and achievements include:</p>
      <ul class="list-none">
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Personnel Management and Development:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Hired, onboarded, and trained new associates to maintain a skilled workforce</li>
            <li class="mb-2 relative before:content-['🩷']">Guided and mentored new PICs and department managers, ensuring their preparedness for leadership roles</li>
            <li class="mb-2 relative before:content-['🩷']">Addressed associate concerns and collaboratively developed solutions to maintain a positive work environment</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Safety and Compliance:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Maintained compliance with OSHA safety regulations across all store operations</li>
            <li class="mb-2 relative before:content-['🩷']">Implemented a comprehensive safety program within the store to ensure employee and customer well-being</li>
            <li class="mb-2 relative before:content-['🩷']">Enforced company policies and procedures, addressing violations appropriately</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Financial Management and Auditing:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Audited weekly bookkeeping records for cash shortages and discrepancies, ensuring financial accuracy</li>
            <li class="mb-2 relative before:content-['🩷']">Assisted with processing weekly payroll and timekeeping as needed</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Operational Excellence:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Oversaw day-to-day store operations to maintain exceptional service standards</li>
            <li class="mb-2 relative before:content-['🩷']">Upheld high service expectations and promoted a positive work environment</li>
            <li class="mb-2 relative before:content-['🩷']">Contributed to the efficient management of store operations through various initiatives</li>
          </ul>
        </li>
      </ul>
    </div>`,
    end:   new Date("5 April 2020"),
    link:  "https://www.safeway.com",
    logo:  "safeway.png",
    start: new Date("5 August 2009"),
    title: "Service Operations Manager",
    type:  "fixed",
  },
  {
    company:     "Vancouver School of Arts and Academics",
    description: `<div class="pl-4">
      <p>As a student at the Vancouver School of Arts and Academics, I immersed myself in a diverse and enriching artistic environment, with a primary focus on music and a secondary emphasis on theatre. This multidisciplinary approach allowed me to develop a broad range of skills across various art forms, fostering my creativity and artistic expression.</p>

      <p>My dedication to music, particularly in band, saw me master multiple instruments including the clarinet, piano, bassoon, and saxophone. This comprehensive musical education enhanced my understanding of different musical styles and techniques, as well as my ability to collaborate within an ensemble setting.</p>

      <p>In theatre, I honed my skills both as an actor and as a theatre technician, gaining a well-rounded understanding of stage production. Additionally, I explored other artistic disciplines such as dance, visual arts, filmography, and literature, further broadening my creative horizons and interdisciplinary approach to the arts.</p>

      <p>Key areas of focus and achievements include:</p>
      <ul class="list-none">
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Music:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Participated actively in the school band program</li>
            <li class="mb-2 relative before:content-['🩷']">Developed proficiency in multiple instruments: clarinet, piano, bassoon, and saxophone</li>
            <li class="mb-2 relative before:content-['🩷']">Gained experience in ensemble playing and musical collaboration</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Theatre:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Performed as an actor in various school productions</li>
            <li class="mb-2 relative before:content-['🩷']">Gained technical theatre experience, working behind the scenes on productions</li>
            <li class="mb-2 relative before:content-['🩷']">Developed a comprehensive understanding of stage production processes</li>
          </ul>
        </li>
        <li class="mb-2 relative before:content-['🩵'] ml-[-1rem]">Interdisciplinary Arts Exploration:
          <ul class="pl-4 mt-2">
            <li class="mb-2 relative before:content-['🩷']">Explored dance, enhancing physical expression and movement skills</li>
            <li class="mb-2 relative before:content-['🩷']">Engaged in visual arts projects, developing artistic techniques and creative vision</li>
            <li class="mb-2 relative before:content-['🩷']">Participated in filmography studies, gaining insight into visual storytelling</li>
            <li class="mb-2 relative before:content-['🩷']">Studied literature, enhancing writing and analytical skills</li>
          </ul>
        </li>
      </ul>
    </div>`,
    end:   new Date("5 June 2009"),
    link:  "https://arts.vansd.org/",
    logo:  "vsaa.png",
    start: new Date("5 September 2001"),
    title: "Student",
    type:  "volunteer",
  },
];
